from distutils import dir_util
from os.path import dirname, join, exists
from urllib.request import urlretrieve

from django.apps import AppConfig


class MermaidConfig(AppConfig):
    name = "django_mermaid"

    def ready(self):
        """Download mermaid.js from CDN if not already present"""
        cdn = "https://cdnjs.cloudflare.com/ajax/libs/mermaid/9.4.3/mermaid.js"
        static = join(dirname(__file__), "static")
        if not exists(join(static, "mermaid.js")):
            dir_util.create_tree(static, ["mermaid.js"])
            urlretrieve(cdn, join(static, "mermaid.js"))



from django import template
from django.templatetags.static import static
from django.utils.safestring import mark_safe

register = template.Library()


@register.simple_tag
@mark_safe
def mermaid(diagram="", theme="default"):
    """Render a mermaid diagram.

    :param diagram: The mermaid diagram definition
    :param theme: The mermaid theme to use (default, forest, dark, neutral). See https://mermaid.js.org/config/theming.
    """

    html = "<div class=\"mermaid\">%s</div><script src=\"%s\"></script>" % (diagram, static("mermaid.js"))
    return html + "<script>mermaid.initialize({\"startOnLoad\": true, theme: \"%s\"});</script>" % theme
